@@ -6,34 +6,30 @@
 #ifndef _SETTINGS_H_
 #define _SETTINGS_H_
 
-#include "actions/actions.h"
 #include "action_data/action_data_group.h"
+#include "actions/actions.h"
 #include <kshortcut.h>
 
 class KConfig;
 
 namespace KHotKeys
 {
-
 class ActionDataGroup;
 
 /**
  * How to handle imports.
  */
-enum ImportType
-    {
-    ImportNone,  //!< no import is done
-    ImportAsk,   //!< if already imported before, ask (called from GUI)
-    ImportSilent //!< if already imported before, ignore (called from the update script)
-    };
-
-enum ActionState
-    {
-    Retain,      //!< Keep the current state
-    Enabled,     //!< Enable all actions
-    Disabled     //!< Disable all actions
-    };
+enum ImportType {
+    ImportNone, //!< no import is done
+    ImportAsk, //!< if already imported before, ask (called from GUI)
+    ImportSilent, //!< if already imported before, ignore (called from the update script)
+};
 
+enum ActionState {
+    Retain, //!< Keep the current state
+    Enabled, //!< Enable all actions
+    Disabled, //!< Disable all actions
+};
 
 /**
  * Handles KHotKeys Settings.
@@ -42,10 +38,9 @@ enum ActionState
  */
 class Q_DECL_EXPORT Settings
 {
-    Q_DISABLE_COPY( Settings )
+    Q_DISABLE_COPY(Settings)
 
 public:
-
     Settings();
     ~Settings();
 
@@ -79,23 +74,14 @@ public:
      * @param id    use id for the exported file.
      * @param state state to use for exported actions
      */
-    void exportTo(
-            ActionDataBase *what,
-            KConfigBase &config,
-            const QString &id,
-            ActionState state,
-            bool allowMerging);
+    void exportTo(ActionDataBase *what, KConfigBase &config, const QString &id, ActionState state, bool allowMerging);
 
     /**
      * Import settings from \a cfg_P.
      */
-    bool import(KConfig& cfg_P, ImportType ask, ActionState state);
+    bool import(KConfig &cfg_P, ImportType ask, ActionState state);
 
-    bool importFrom(
-            ActionDataGroup *parent,
-            KConfigBase const &config,
-            ImportType ask,
-            ActionState state);
+    bool importFrom(ActionDataGroup *parent, KConfigBase const &config, ImportType ask, ActionState state);
 
     /**
      * Get all actions
@@ -104,7 +90,7 @@ public:
     const ActionDataGroup *actions() const;
 
     /**
-     * Take the actions. 
+     * Take the actions.
      *
      * \note Ownership is transferred to you. Subsequent calls to action() will
      * return 0
@@ -112,12 +98,12 @@ public:
     ActionDataGroup *takeActions();
 
     /**
-     * Set the actions. 
+     * Set the actions.
      *
      * \note Ownership is taken. The current action list will be deleted. If
      * \@a actions is nullptr the method will create a new ActionDataGroup
      */
-    void setActions( ActionDataGroup *actions );
+    void setActions(ActionDataGroup *actions);
 
     /**
      * @name KHotkeys Daemon
@@ -153,12 +139,12 @@ public:
     bool areGesturesDisabled() const;
 
     int gestureMouseButton() const;
-    void setGestureMouseButton( int );
+    void setGestureMouseButton(int);
 
     int gestureTimeOut() const;
     void setGestureTimeOut(int);
 
-    void setGesturesExclude( Windowdef_list *gestures );
+    void setGesturesExclude(Windowdef_list *gestures);
     Windowdef_list *gesturesExclude();
     const Windowdef_list *gesturesExclude() const;
     //@}
@@ -167,7 +153,7 @@ public:
      * @name Voice Commands
      */
     //@{
-    void setVoiceShortcut( const QKeySequence &shortcut );
+    void setVoiceShortcut(const QKeySequence &shortcut);
     QKeySequence voiceShortcut() const;
     //@}
 
@@ -179,7 +165,6 @@ public:
     static bool isOutdated;
 
 protected:
-
     /**
      * Read settings from \a cfg_P.
      *
@@ -188,11 +173,7 @@ protected:
      * @param include_disabled should we read disabled actions?
      * @param state enable, disable or keep the actions enabled state
      */
-    bool read_settings(
-            ActionDataGroup *root,
-            KConfigBase const &config,
-            bool include_disabled,
-            ActionState state);
+    bool read_settings(ActionDataGroup *root, KConfigBase const &config, bool include_disabled, ActionState state);
 
     /**
      * Make sure all System Groups exists
@@ -200,14 +181,13 @@ protected:
     void validate();
 
 private:
-
     // Reset all values. No defaults are loaded
     void reinitialize();
 
     /**
      * TODO
      */
-    ActionDataGroup* m_actions;
+    ActionDataGroup *m_actions;
 
     /**
      * @name Gestures
@@ -231,7 +211,7 @@ private:
     /**
      * Windows to exclude from gestures
      */
-    Windowdef_list* gestures_exclude;
+    Windowdef_list *gestures_exclude;
     //@}
 
     /**
