@@ -6,37 +6,39 @@
 #include "soundrecorder.h"
 
 #include <QDebug>
-#include <klocale.h>
 #include <QTimer>
 #include <klibrary.h>
+#include <klocale.h>
 
 #include "khotkeysglobal.h"
 
 namespace KHotKeys
 {
-
 SoundRecorder::create_ptr SoundRecorder::create_fun = NULL;
 
-bool SoundRecorder::init( KLibrary* lib )
+bool SoundRecorder::init(KLibrary *lib)
 {
 #ifdef HAVE_ARTS
-    if( create_fun == NULL && lib != NULL )
-        create_fun = (create_ptr) lib->symbol( "khotkeys_soundrecorder_create" );
+    if (create_fun == NULL && lib != NULL)
+        create_fun = (create_ptr)lib->symbol("khotkeys_soundrecorder_create");
 #endif
-//    qDebug() << "soundrecorder:" << create_fun << ":" << lib;
+    //    qDebug() << "soundrecorder:" << create_fun << ":" << lib;
     return create_fun != NULL;
 }
 
-SoundRecorder* SoundRecorder::create( QObject* parent )
+SoundRecorder *SoundRecorder::create(QObject *parent)
 {
 #ifdef HAVE_ARTS
-    if( create_fun != NULL )
-        return create_fun( parent, name );
+    if (create_fun != NULL)
+        return create_fun(parent, name);
 #endif
-    return new SoundRecorder( parent );
+    return new SoundRecorder(parent);
 }
 
-SoundRecorder::SoundRecorder(QObject *parent)  : QObject(parent) {}
+SoundRecorder::SoundRecorder(QObject *parent)
+    : QObject(parent)
+{
+}
 
 SoundRecorder::~SoundRecorder()
 {
@@ -54,11 +56,10 @@ void SoundRecorder::abort()
 {
 }
 
-
 Sound SoundRecorder::sound()
 {
-	Sound s;
-	return s;
+    Sound s;
+    return s;
 }
 
 }
